All calls to the trading API are sent via HTTP POST. The POST data itself is signed with your key's secret according to the HMAC-SHA512 method.
trading.base.urlA length-one character vector. Represents the poloniex trading API web service base url.
keyA length-one character vector. Represents the public key of your Poloniex trading account
secretA length-one character vector. Represents the private key of your Poloniex trading account
commandsA list containing Key/Value string pairs. Represents the command strings of the associated trading API functions.